==> tine20-allinone_2019.12.5.tar.bz2: Crm/js/Crm-lang-it-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Italian (http://www.transifex.com/tine20/tine20/language/it/)\nLanguage: it\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Customer"
: "Cliente"

, "State"
: "Stato"

, "Role"
: "Ruolo"

, "Source"
: "Sorgente"

, "Start"
: "Inizio"

, "Scheduled end"
: "Fine schedulata"

, "End"
: "Fine"

, "Turnover"
: "Fatturato"

, "Probability"
: "Probabilità"

, "Folder"
: "Cartella"

, "Updated by"
: "Aggiornato da"

, "Updated Fields:"
: "Campi aggiornati:"

, "'%s' changed from '%s' to '%s'."
: ""

, "Tags"
: "Tag"

, "Lead %s has been changed"
: "Il cliente potenziale %s è stato modificato"

, "Lead %s has been deleted"
: ""

, "Lead %s has been created"
: "Il lead %s è stato creato"

, "Lead Data"
: "Dati cliente potenziale"

, "Leadstate"
: "Stato cliente potenziale"

, "Leadtype"
: "Tipo cliente potenziale"

, "Leadsource"
: "Sorgente cliente potenziale"

, "End Scheduled"
: "Fine schedulata"

, "Contacts"
: "Contatti"

, "Address"
: "Indirizzo"

, "Telephone"
: "Telefono"

, "Email"
: "Email"

, "Tasks"
: "Compiti"

, "Due Date"
: "Data prevista completamento"

, "Priority"
: "Priorità"

, "Products"
: "Prodotti"

, "low"
: "basso"

, "normal"
: "normale"

, "high"
: "alto"

, "urgent"
: "urgente"

, "All leads I have read grants for"
: "Tutti i potenziali di cui ho il permesso di lettura"

, "Last modified by me"
: "Ultimo modificato da me"

, "All leads that I have last modified"
: "Tutti i leads che ho modificato"

, "My leads"
: "Miei Leads"

, "All leads that I am responsible for"
: "Tutti i leads di cui sono responsabile"

, "Leads with overdue tasks"
: "Leads con attività scadute"

, "All leads"
: "Tutti i leads"

, "Default Lead List"
: "Lista dei lead di default"

, "The default list for new leads"
: "Lista predefinita per clienti potenziali"

, "Get Notification Emails"
: "Ricevi Notifiche Email"

, "The level of actions you want to be notified about."
: "Il livello di azioni per cui vuoi essere notificato."

, "Send Notifications Emails for own actions"
: "Invia Notifiche Email per le tue azioni"

, "Get notifications emails for actions you did yourself"
: "Ricevi notifiche email per le azione compiute da te stesso"

, "Send Notifications Emails to responsible"
: ""

, "Get notifications emails for action to responsible"
: ""

, "Send Notifications Emails to customer"
: ""

, "Get notifications emails for action to customer"
: ""

, "Send Notifications Emails to partner"
: ""

, "Get notifications emails for action to partner"
: ""

, "Default Favorite"
: "Preferito di Default"

, "The default favorite which is loaded on crm startup"
: "Il preferito di default che è caricato all'apertura del crm"

, "manage shared lead folders"
: "gestisci cartelle condivise dei clienti potenziali"

, "Create new shared lead folders"
: "Crea nuove cartelle condivise per clienti potenziali"

, "manage shared leads favorites"
: "gestisci i leads condivisi preferiti"

, "Create or update shared leads favorites"
: "Crea o aggiorna i leads condivisi preferiti"

, "Contact"
: "Contatto"

, "CRM Role"
: "Ruolo CRM"

, "Lead, Leads"
: [
  "Cliente potenziale"
 ,"Clienti potenziali"

]
, "lead list, lead lists"
: [
  "Lista dei Lead"
 ,"Liste dei Leads"

]
, "lead lists"
: "Liste dei Leads"

, "Quick Search"
: "Ricerca veloce"

, "Lead name"
: "Nome cliente potenziale"

, "Last Modified Time"
: "Data di ultima modifica"

, "Last Modified By"
: "Ultima modifica di"

, "Creation Time"
: "Data creazione"

, "Created By"
: "Creato da"

, "Estimated end"
: "Fine prevista"

, "Resubmission Date"
: ""

, "X Lead"
: ""

, "Archived"
: ""

, "Partner"
: "Partner"

, "Phone"
: "Telefono"

, "Mobile"
: "Cellulare"

, "Fax"
: "Fax"

, "E-Mail"
: "E-Mail"

, "Web"
: "Indirizzo sito web"

, "Street"
: ""

, "Postalcode"
: ""

, "City"
: ""

, "Status"
: "Stato"

, "Change type to Customer"
: "Cambia tipo al Cliente"

, "Responsible"
: "Responsabile"

, "Change type to Responsible"
: "Cambia tipo al Responsabile"

, "Change type to Partner"
: "Cambia tipo al Partner"

, "Change contact type"
: "Cambia tipo contatto"

, "Search for Contacts to add ..."
: "Ricerca Contatti da aggiungere..."

, "Name"
: "Nome"

, "Data"
: "Data"

, "Cellphone"
: "Cellulare"

, "Add new {0}"
: "Aggiungi nuovo {0}"

, "Unlink {0}"
: "Togli collegamento {0}"

, "Unlink selected {0}"
: "Togli collegamento selezionato {0}"

, "Edit {0}"
: "Modifica {0}"

, "Edit selected {0}"
: "Modifica {0} selezionato"

, "No Tasks to display"
: "Nessun compito da visualizzare"

, "Summary"
: "Sommario"

, "Add a task..."
: "Aggiungi un compito..."

, "Percent"
: "Percentuale"

, "Organizer"
: ""

, "Please choose the Lead to add the contacts to"
: "Si prega di scegliere il Lead da aggiungere ai contatti"

, "Please select the attenders' role"
: "Prego seleziona il ruolo del partecipante"

, "Select Lead"
: "Seleziona Lead"

, "Select Role"
: "Seleziona Ruolo"

, "Adding {0} contacts to lead"
: "Aggiunti {0} contatti al lead"

, "Probable Turnover"
: "Fatturato probabile"

, "Import leads"
: ""

, "You do not have the run right for the Tasks application or it is not activated."
: "Non si ha il diritto di esecuzione per l'applicazione Attività o non è attivato."

, "You do not have the run right for the Sales application or it is not activated."
: "Non si ha il diritto di esecuzione per l'applicazione Vendite o non è attivato."

, "Enter lead name"
: ""

, "Expected turnover"
: "Fatturato previsto"

, "Description"
: "Descrizione"

, "Enter description"
: "Inserisci descrizione"

, "New Lead"
: "Nuovo Lead"

, "Product"
: "Prodotto"

, "Price"
: "Prezzo"

, "Quantity"
: "Quantità"

, "Search for Products to add ..."
: "Ricerca Prodotti da aggiungere..."

, "Edit new lead"
: ""

, "The following leads have just been imported into lead list %s"
: ""

, "%s new leads have been imported"
: ""

, "Lead CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Task"
: "Attività"

, "Lead States Available"
: ""

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: "aperto"

, "contacted"
: "contattato"

, "waiting for feedback"
: "in attesa di feedback"

, "quote sent"
: "offerta inviata"

, "accepted"
: "accettato"

, "lost"
: "perso"

, "Lead Sources Available"
: ""

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: ""

, "Possible lead types."
: ""

, "Reseller"
: "Rivenditore"

, "Enabled Features"
: ""

, "Enabled Features in Crm Application."
: ""

, "Lead Import"
: ""

, "Add new task on lead import"
: ""

, "Automatically creates a task for the responsible person if a new lead is imported."
: ""

, "Send notification email on lead import"
: ""

, "Sends an email to all responsible persons for the imported leads."
: ""

, "Lead duplicate check fields"
: ""

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "Lead"
: "Cliente potenziale"

, "lead list"
: "Lista dei Lead"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.03.4.tar.bz2: Crm/js/Crm-lang-it-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Italian (http://www.transifex.com/tine20/tine20/language/it/)\nLanguage: it\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "All leads"
: "Tutti i leads"

, "Default Lead List"
: "Lista dei lead di default"

, "The default list for new leads"
: "Lista predefinita per clienti potenziali"

, "Get Notification E-mails"
: ""

, "The level of actions you want to be notified about."
: "Il livello di azioni per cui vuoi essere notificato."

, "Send Notifications e-mails for own actions"
: ""

, "Get notifications e-mails for actions you did yourself"
: ""

, "Send Notifications e-mails to responsible"
: ""

, "Get notifications e-mails for action to responsible"
: ""

, "Send Notifications e-mails to customer"
: ""

, "Get notifications e-mails for action to customer"
: ""

, "Send Notifications e-mails to partner"
: ""

, "Get notifications e-mails for action to partner"
: ""

, "Default Favorite"
: "Preferito di Default"

, "The default favorite which is loaded on crm startup"
: "Il preferito di default che è caricato all'apertura del crm"

, "New Lead"
: "Nuovo Lead"

, "Tags"
: "Tag"

, "Lead name"
: "Nome cliente potenziale"

, "Responsible"
: "Responsabile"

, "Partner"
: "Partner"

, "Customer"
: "Cliente"

, "Leadstate"
: "Stato cliente potenziale"

, "Leadtype"
: "Tipo cliente potenziale"

, "Leadsource"
: "Sorgente cliente potenziale"

, "Probability"
: "Probabilità"

, "Turnover"
: "Fatturato"

, "Estimated end"
: "Fine prevista"

, "Probable Turnover"
: "Fatturato probabile"

, "Resubmission Date"
: ""

, "Import leads"
: ""

, "Contact"
: "Contatto"

, "CRM Role"
: "Ruolo CRM"

, "Tasks"
: "Compiti"

, "No Tasks to display"
: "Nessun compito da visualizzare"

, "Summary"
: "Sommario"

, "Add a task..."
: "Aggiungi un compito..."

, "Due Date"
: "Data prevista completamento"

, "Priority"
: "Priorità"

, "Percent"
: "Percentuale"

, "Status"
: "Stato"

, "Organizer"
: ""

, "Add new {0}"
: "Aggiungi nuovo {0}"

, "Unlink {0}"
: "Togli collegamento {0}"

, "Unlink selected {0}"
: "Togli collegamento selezionato {0}"

, "Edit {0}"
: "Modifica {0}"

, "Edit selected {0}"
: "Modifica {0} selezionato"

, "Please choose the Lead to add the contacts to"
: "Si prega di scegliere il Lead da aggiungere ai contatti"

, "Please select the attenders' role"
: "Prego seleziona il ruolo del partecipante"

, "Lead, Leads"
: [
  "Cliente potenziale"
 ,"Clienti potenziali"

]
, "Select Lead"
: "Seleziona Lead"

, "Role"
: "Ruolo"

, "Select Role"
: "Seleziona Ruolo"

, "Adding {0} contacts to lead"
: "Aggiunti {0} contatti al lead"

, "Phone"
: "Telefono"

, "Mobile"
: "Cellulare"

, "Fax"
: "Fax"

, "E-Mail"
: "E-Mail"

, "Web"
: "Indirizzo sito web"

, "Street"
: ""

, "Postalcode"
: ""

, "City"
: ""

, "Start"
: "Inizio"

, "Change type to Customer"
: "Cambia tipo al Cliente"

, "Change type to Responsible"
: "Cambia tipo al Responsabile"

, "Change type to Partner"
: "Cambia tipo al Partner"

, "Change contact type"
: "Cambia tipo contatto"

, "Search for Contacts to add ..."
: "Ricerca Contatti da aggiungere..."

, "Name"
: "Nome"

, "Address"
: "Indirizzo"

, "Data"
: "Data"

, "Cellphone"
: "Cellulare"

, "End"
: "Fine"

, "You do not have the run right for the Tasks application or it is not activated."
: "Non si ha il diritto di esecuzione per l'applicazione Attività o non è attivato."

, "Products"
: "Prodotti"

, "You do not have the run right for the Sales application or it is not activated."
: "Non si ha il diritto di esecuzione per l'applicazione Vendite o non è attivato."

, "Enter lead name"
: ""

, "Expected turnover"
: "Fatturato previsto"

, "Description"
: "Descrizione"

, "Enter description"
: "Inserisci descrizione"

, "lead list, lead lists"
: [
  "Lista dei Lead"
 ,"Liste dei Leads"

]
, "lead lists"
: "Liste dei Leads"

, "Quick Search"
: "Ricerca veloce"

, "Last Modified Time"
: "Data di ultima modifica"

, "Last Modified By"
: "Ultima modifica di"

, "Creation Time"
: "Data creazione"

, "Created By"
: "Creato da"

, "X Lead"
: ""

, "Archived"
: ""

, "Product"
: "Prodotto"

, "Price"
: "Prezzo"

, "Quantity"
: "Quantità"

, "Search for Products to add ..."
: "Ricerca Prodotti da aggiungere..."

, "All leads I have read grants for"
: "Tutti i potenziali di cui ho il permesso di lettura"

, "Last modified by me"
: "Ultimo modificato da me"

, "All leads that I have last modified"
: "Tutti i leads che ho modificato"

, "My leads"
: "Miei Leads"

, "All leads that I am responsible for"
: "Tutti i leads di cui sono responsabile"

, "Leads with overdue tasks"
: "Leads con attività scadute"

, "Lead States Available"
: ""

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: "aperto"

, "contacted"
: "contattato"

, "waiting for feedback"
: "in attesa di feedback"

, "quote sent"
: "offerta inviata"

, "accepted"
: "accettato"

, "lost"
: "perso"

, "Lead Sources Available"
: ""

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: ""

, "Possible lead types."
: ""

, "Reseller"
: "Rivenditore"

, "Enabled Features"
: ""

, "Enabled Features in CRM Application."
: ""

, "Lead Import"
: ""

, "Add new task on lead import"
: ""

, "Automatically creates a task for the responsible person if a new lead is imported."
: ""

, "Send notification e-mail on lead import"
: ""

, "Sends an e-mail to all responsible persons for the imported leads."
: ""

, "Lead duplicate check fields"
: ""

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "State"
: "Stato"

, "Source"
: "Sorgente"

, "Scheduled end"
: "Fine schedulata"

, "Folder"
: "Cartella"

, "Updated by"
: "Aggiornato da"

, "Updated Fields:"
: "Campi aggiornati:"

, "'%s' changed from '%s' to '%s'."
: ""

, "Lead %s has been changed"
: "Il cliente potenziale %s è stato modificato"

, "Lead %s has been deleted"
: ""

, "Lead %s has been created"
: "Il lead %s è stato creato"

, "Task"
: "Attività"

, "Lead Data"
: "Dati cliente potenziale"

, "End Scheduled"
: "Fine schedulata"

, "Contacts"
: "Contatti"

, "Telephone"
: "Telefono"

, "Email"
: "Email"

, "low"
: "basso"

, "normal"
: "normale"

, "high"
: "alto"

, "urgent"
: "urgente"

, "Lead CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Edit new lead"
: ""

, "The following leads have just been imported into lead list %s"
: ""

, "%s new leads have been imported"
: ""

, "manage shared lead folders"
: "gestisci cartelle condivise dei clienti potenziali"

, "Create new shared lead folders"
: "Crea nuove cartelle condivise per clienti potenziali"

, "manage shared leads favorites"
: "gestisci i leads condivisi preferiti"

, "Create or update shared leads favorites"
: "Crea o aggiorna i leads condivisi preferiti"




, "Lead"
: "Cliente potenziale"

, "lead list"
: "Lista dei Lead"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
